@@ -282,17 +282,9 @@ module YARD
             end
           end
 
-          if token == :symbeg
-            @symbol = [:symbol, data, [lineno, charno]]
-          elsif @symbol
-            case token
-            when :tstring_content
-              @symbol[1] += data
-            when :tstring_end, :const, :ident
-              @symbol[1] += data
-              @tokens << @symbol
-              @symbol = nil
-            end
+          if @tokens.last && (@tokens.last[0] == :symbeg ||
+              (@tokens.last[0] == :symbol && token.to_s =~ /^tstring/))
+            @tokens[-1] = [:symbol, @tokens.last[1] + data, @tokens.last[2]]
           elsif @heredoc_state == :started
             @heredoc_tokens << [token, data, [lineno, charno]]
 
@@ -341,6 +333,7 @@ module YARD
         undef on_bodystmt
         undef on_top_const_ref
         undef on_const_path_ref
+        undef on_dyna_symbol
 
         def on_program(*args)
           args.first
@@ -418,6 +411,16 @@ module YARD
           visit_ns_token(:rbracket, tok, false)
         end
 
+        def on_dyna_symbol(sym)
+          rng = if sym.source_range.size == 0 # rubocop:disable Style/ZeroLengthPredicate
+                  (sym.source_range.begin - 3)...sym.source_range.end
+                else
+                  (sym.source_range.begin - 2)..(sym.source_range.end + 1)
+                end
+          AstNode.new(:dyna_symbol, [sym], :line => lineno..lineno,
+            :listline => lineno..lineno, :listchar => rng, :char => rng)
+        end
+
         def on_top_const_ref(*args)
           type = :top_const_ref
           node = AstNode.node_class_for(type).new(type, args)
@@ -489,7 +492,8 @@ module YARD
         end
 
         def on_string_content(*args)
-          AstNode.new(:string_content, args, :listline => lineno..lineno, :listchar => charno..charno)
+          chr_rng = args.empty? ? charno...charno : charno..charno
+          AstNode.new(:string_content, args, :listline => lineno..lineno, :listchar => chr_rng)
         end
 
         def on_rescue(exc, *args)
@@ -608,7 +612,7 @@ module YARD
 
         def insert_comments
           root.traverse do |node|
-            next if node.type == :comment || node.type == :list || node.parent.type != :list
+            next if %i{comment void_stmt list}.include?(node.type) || node.parent.type != :list
 
             # never attach comments to if/unless mod nodes
             if node.type == :if_mod || node.type == :unless_mod
